@@ -26,7 +26,8 @@ void KEventHistoryDlg::addEvent( WpaMsg msg )
     if (item == NULL)
         return;
     lvEventHistory->ensureItemVisible(item);
-    lvEventHistory->setSelected(item, false);}
+    lvEventHistory->setSelected(item, false);
+}
 
 void KEventHistoryDlg::addEvents( WpaMsgList msgs )
 {
