@@ -101,3 +101,15 @@ void KProfileConfig::dhcpState( int state )
 {
 
 }
+
+
+void KProfileConfig::dnsAddDomain()
+{
+
+}
+
+
+void KProfileConfig::dnsRemoveDomain()
+{
+
+}
