@@ -1,6 +1,12 @@
-
 #ifndef KSTARTSUPPLICANTDLG_H
 #define KSTARTSUPPLICANTDLG_H
+/** KWlan
+ *
+ *  This File is part of KWlan, a network Manager for KDE.
+ *  KWlan is distributed under LGPL license.
+ *
+ *	@author Thomas Michel <tom.michel@arcor.de>
+ */
 
 #include "kstartsupplicant.h"
 
