@@ -1,10 +1,18 @@
 #ifndef __KWLANAPPLICATION__ 
 #define __KWLANAPPLICATION__ 
+/** KWlan
+ *
+ *  This File is part of KWlan, a network Manager for KDE.
+ *  KWlan is distributed under LGPL license.
+ *
+ *	@author Thomas Michel <tom.michel@arcor.de>
+ */
 
 #include <kuniqueapplication.h>
 
 class KProcess;
 class QString;
+class KDialup;
 
 class KWlanApplication : public KUniqueApplication
 {
@@ -13,9 +21,6 @@ class KWlanApplication : public KUniqueApplication
         KWlanApplication(bool allowStyles=true, bool GUIenabled=true, bool configUnique=false);
         ~KWlanApplication();
         void init();
-    public slots:
-        void ifconfigProcessExited( KProcess* process );
-        void ifconfigProcessStdout( KProcess* process, char* buffer, int buflen );
     private:
         QString m_ifconfigStdout;
 
