@@ -38,14 +38,18 @@ void KWlanSettingsDlg::Ok()
     }
     m_configuration->m_startWpa = cbWpa->isChecked();
     m_configuration->m_startWpaNoQuestion = cbWpaNoQuestion->isChecked();
-    m_configuration->m_startMinimized = cbMinimized->isChecked();
-    PasswordCache().m_pwexpire = sbPasswordTime->value();
     m_configuration->writeSettings();
-    PasswordCache().writePasswordExpire();
     QWidget::close(true);
 }
 
+void KWlanSettingsDlg::setConfiguraton(Configuration *conf)
+{
+    m_configuration = conf;
+    if (!conf) return;
+    cbWpa->setChecked(m_configuration->m_startWpa);
+    cbWpaNoQuestion->setChecked(m_configuration->m_startWpaNoQuestion);
 
+}
 
 #include "kwlansettingsdlg.moc"
 
