@@ -1,6 +1,12 @@
-
 #ifndef KWLANSETTINGSDLG_H
 #define KWLANSETTINGSDLG_H
+/** KWlan
+ *
+ *  This File is part of KWlan, a network Manager for KDE.
+ *  KWlan is distributed under LGPL license.
+ *
+ *	@author Thomas Michel <tom.michel@arcor.de>
+ */
 
 #include "kwlansettings.h"
 
@@ -14,10 +20,7 @@ class KWlanSettingsDlg : public KWlanSettings
 public:
   KWlanSettingsDlg(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
   ~KWlanSettingsDlg();
-  void setConfiguraton(Configuration *conf)
-  {
-      m_configuration = conf;
-  }
+  void setConfiguraton(Configuration *conf);
   /*$PUBLIC_FUNCTIONS$*/
 
 public slots:
