@@ -1,5 +1,12 @@
 #ifndef __KWLANSUCLIENT__
 #define __KWLANSUCLIENT__
+/** KWlan
+ *
+ *  This File is part of KWlan, a network Manager for KDE.
+ *  KWlan is distributed under LGPL license.
+ *
+ *	@author Thomas Michel <tom.michel@arcor.de>
+ */
 
 #include <kdesu/client.h>
 #include <qstring.h>
